==> familia_0.1.tar.gz: familia/src/file/name.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_NAME_H
#define _FILE_NAME_H

#include <glibmm/ustring.h>

class Name {
public:
  typedef Name _Myt;
  typedef Glib::ustring _String;
protected:

public:
  _String first;
  _String middle;
  _String last;
  Name();
  virtual ~Name();

  void setFirst(_String str);
  void setMiddle(_String str);
  void setLast(_String str);

  _String getFirst();
  _String getMiddle();
  _String getLast();
};

#endif

==> familia_0.1.2.tar.gz: familia/src/file/name.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_NAME_H
#define _FILE_NAME_H

#include <glibmm/ustring.h>

class Name {
public:
  typedef Name _Myt;
  typedef Glib::ustring String;
protected:

public:
  String first;
  String middle;
  String last;
  Name();
  virtual ~Name();

  void setFirst(String str);
  void setMiddle(String str);
  void setLast(String str);

  String getFirst();
  String getMiddle();
  String getLast();
};

#endif
